pub(super) struct GlobalBarrierWorkerContextImpl {
scheduled_barriers: ScheduledBarriers,
status: Arc<ArcSwap<BarrierManagerStatus>>,
pub(super) metadata_manager: MetadataManager,
hummock_manager: HummockManagerRef,
source_manager: SourceManagerRef,
_scale_controller: ScaleControllerRef,
pub(super) env: MetaSrvEnv,
barrier_scheduler: BarrierScheduler,
pub(super) refresh_manager: GlobalRefreshManagerRef,
sink_manager: SinkCoordinatorManager,
pub(super) iceberg_v3_sink_manager: IcebergV3SinkManager,
}Fields
scheduled_barriers: ScheduledBarriersstatus: Arc<ArcSwap<BarrierManagerStatus>>metadata_manager: MetadataManagerhummock_manager: HummockManagerRefsource_manager: SourceManagerRef_scale_controller: ScaleControllerRefenv: MetaSrvEnvbarrier_scheduler: BarrierSchedulerBarrier scheduler for scheduling load finish commands
refresh_manager: GlobalRefreshManagerRefsink_manager: SinkCoordinatorManagericeberg_v3_sink_manager: IcebergV3SinkManagerImplementations
Sourceimpl GlobalBarrierWorkerContextImpl
impl GlobalBarrierWorkerContextImpl
async fn get_source_database_id_for_refresh_stage( &self, table_id: TableId, associated_source_id: SourceId, stage: &'static str, ) -> MetaResult<Option<DatabaseId>>
fn set_status(&self, new_status: BarrierManagerStatus)
Sourceasync fn load_batch_refresh_trigger_context_impl(
&self,
job_id: JobId,
database_id: DatabaseId,
last_committed_epoch: u64,
) -> MetaResult<BatchRefreshJobTriggerContext>
async fn load_batch_refresh_trigger_context_impl( &self, job_id: JobId, database_id: DatabaseId, last_committed_epoch: u64, ) -> MetaResult<BatchRefreshJobTriggerContext>
Load the context metadata and resolve upstream log epochs for a batch refresh trigger.
Sourceimpl GlobalBarrierWorkerContextImpl
impl GlobalBarrierWorkerContextImpl
fn resolve_job_committed_epoch( job_id: JobId, fragments: &HashMap<FragmentId, LoadedFragment>, state_table_committed_epochs: &HashMap<TableId, u64>, ) -> MetaResult<u64>
async fn finish_completed_batch_refresh_background_jobs( &self, recovery_context: &LoadedRecoveryContext, state_table_committed_epochs: &HashMap<TableId, u64>, background_jobs: &mut HashSet<JobId>, ) -> MetaResult<()>
async fn apply_pre_applied_drop_cancel( &self, database_id: Option<DatabaseId>, ) -> MetaResult<bool>
Sourceasync fn clean_dirty_streaming_jobs(
&self,
database_id: Option<DatabaseId>,
) -> MetaResult<()>
async fn clean_dirty_streaming_jobs( &self, database_id: Option<DatabaseId>, ) -> MetaResult<()>
Clean catalogs for creating streaming jobs that are in foreground mode or table fragments not persisted.
async fn reset_sink_coordinator( &self, database_id: Option<DatabaseId>, ) -> MetaResult<()>
Sourceasync fn reregister_iceberg_v3_sinks(
&self,
database_id: Option<DatabaseId>,
) -> MetaResult<()>
async fn reregister_iceberg_v3_sinks( &self, database_id: Option<DatabaseId>, ) -> MetaResult<()>
Re-register iceberg V3 sink commit coordinators after recovery wipes them.
async fn abort_dirty_pending_sink_state( &self, database_id: Option<DatabaseId>, ) -> MetaResult<()>
async fn purge_state_table_from_hummock( &self, all_state_table_ids: &HashSet<TableId>, ) -> MetaResult<()>
async fn list_background_job_progress( &self, database_id: Option<DatabaseId>, ) -> MetaResult<HashSet<JobId>>
async fn load_recovery_context( &self, database_id: Option<DatabaseId>, ) -> MetaResult<LoadedRecoveryContext>
fn resolve_hummock_version_epochs( background_jobs: impl Iterator<Item = (JobId, &HashMap<FragmentId, LoadedFragment>)>, version: &HummockVersion, table_change_log: &TableChangeLogs, ) -> MetaResult<(HashMap<TableId, u64>, HashMap<TableId, Vec<(Vec<u64>, u64)>>)>
pub(super) async fn reload_runtime_info_impl( &self, ) -> MetaResult<BarrierWorkerRuntimeInfoSnapshot>
pub(super) async fn reload_database_runtime_info_impl( &self, database_id: DatabaseId, ) -> MetaResult<DatabaseRuntimeInfoSnapshot>
Sourceimpl GlobalBarrierWorkerContextImpl
impl GlobalBarrierWorkerContextImpl
pub(super) fn new( scheduled_barriers: ScheduledBarriers, status: Arc<ArcSwap<BarrierManagerStatus>>, metadata_manager: MetadataManager, hummock_manager: HummockManagerRef, source_manager: SourceManagerRef, scale_controller: ScaleControllerRef, env: MetaSrvEnv, barrier_scheduler: BarrierScheduler, refresh_manager: GlobalRefreshManagerRef, sink_manager: SinkCoordinatorManager, iceberg_v3_sink_manager: IcebergV3SinkManager, ) -> Self
pub(super) fn status(&self) -> Arc<ArcSwap<BarrierManagerStatus>> ⓘ
Sourceimpl GlobalBarrierWorkerContextImpl
impl GlobalBarrierWorkerContextImpl
pub(super) async fn new_control_stream_impl( &self, node: &WorkerNode, init_request: &PbInitRequest, ) -> MetaResult<StreamingControlHandle>