pub struct InflightDatabaseInfo {
pub(super) database_id: DatabaseId,
jobs: HashMap<JobId, InflightStreamingJobInfo>,
fragment_location: HashMap<FragmentId, JobId>,
pub(super) shared_actor_infos: SharedActorInfos,
}Fields
database_id: DatabaseIdjobs: HashMap<JobId, InflightStreamingJobInfo>fragment_location: HashMap<FragmentId, JobId>Implementations
Sourceimpl InflightDatabaseInfo
impl InflightDatabaseInfo
pub fn fragment_infos(&self) -> impl Iterator<Item = &InflightFragmentInfo> + '_
pub fn contains_job(&self, job_id: JobId) -> bool
pub(super) fn job_id_by_fragment( &self, fragment_id: FragmentId, ) -> Option<JobId>
pub fn fragment(&self, fragment_id: FragmentId) -> &InflightFragmentInfo
pub(super) fn backfill_fragment_ids_for_job( &self, job_id: JobId, ) -> MetaResult<HashSet<FragmentId>>
pub(super) fn is_backfill_fragment( &self, fragment_id: FragmentId, ) -> MetaResult<bool>
pub fn gen_backfill_progress( &self, ) -> impl Iterator<Item = (JobId, BackfillProgress)> + '_
pub fn gen_cdc_progress( &self, ) -> impl Iterator<Item = (JobId, CdcProgress)> + '_
pub fn gen_fragment_backfill_progress(&self) -> Vec<FragmentBackfillProgress>
pub(super) fn may_assign_fragment_cdc_backfill_splits( &mut self, fragment_id: FragmentId, ) -> MetaResult<Option<HashMap<ActorId, PbCdcTableSnapshotSplits>>>
pub(super) fn assign_cdc_backfill_splits( &mut self, job_id: JobId, ) -> MetaResult<Option<HashMap<ActorId, PbCdcTableSnapshotSplits>>>
pub(super) fn apply_collected_command( &mut self, command: &PostCollectCommand, resps: &HashMap<WorkerId, BarrierCompleteResponse>, version_stats: &HummockVersionStats, )
fn iter_creating_job_tracker( &self, ) -> impl Iterator<Item = &CreateMviewProgressTracker>
fn iter_mut_creating_job_tracker( &mut self, ) -> impl Iterator<Item = &mut CreateMviewProgressTracker>
pub(super) fn has_pending_finished_jobs(&self) -> bool
pub(super) fn take_pending_backfill_nodes(&mut self) -> Vec<FragmentId> ⓘ
pub(super) fn take_staging_commit_info(&mut self) -> StagingCommitInfo
pub fn fragment_subscribers( &self, fragment_id: FragmentId, ) -> impl Iterator<Item = SubscriberId> + '_
pub fn job_subscribers( &self, job_id: JobId, ) -> impl Iterator<Item = SubscriberId> + '_
pub fn max_subscription_retention( &self, ) -> impl Iterator<Item = (TableId, u64)> + '_
pub fn register_subscriber( &mut self, job_id: JobId, subscriber_id: SubscriberId, subscriber: SubscriberType, )
pub fn unregister_subscriber( &mut self, job_id: JobId, subscriber_id: SubscriberId, ) -> Option<SubscriberType>
pub fn update_subscription_retention( &mut self, job_id: JobId, subscriber_id: SubscriberId, retention_second: u64, )
fn fragment_mut( &mut self, fragment_id: FragmentId, ) -> (&mut InflightFragmentInfo, JobId)
fn empty_inner( database_id: DatabaseId, shared_actor_infos: SharedActorInfos, ) -> Self
pub fn empty( database_id: DatabaseId, shared_actor_infos: SharedActorInfos, ) -> Self
pub fn recover( database_id: DatabaseId, jobs: impl Iterator<Item = InflightStreamingJobInfo>, shared_actor_infos: SharedActorInfos, ) -> Self
pub fn is_empty(&self) -> bool
pub fn add_existing(&mut self, job: InflightStreamingJobInfo)
Sourcepub(crate) fn pre_apply_new_job(
&mut self,
job_id: JobId,
cdc_table_backfill_tracker: Option<CdcTableBackfillTracker>,
)
pub(crate) fn pre_apply_new_job( &mut self, job_id: JobId, cdc_table_backfill_tracker: Option<CdcTableBackfillTracker>, )
Register a new streaming job entry (with empty fragment_infos).
Sourcepub(crate) fn pre_apply_new_fragments(
&mut self,
fragments: impl IntoIterator<Item = (FragmentId, JobId, InflightFragmentInfo)>,
)
pub(crate) fn pre_apply_new_fragments( &mut self, fragments: impl IntoIterator<Item = (FragmentId, JobId, InflightFragmentInfo)>, )
Add new fragment infos and update shared actor infos.
Sourcepub(crate) fn pre_apply_reschedule(
&mut self,
fragment_id: FragmentId,
new_actors: HashMap<ActorId, InflightActorInfo>,
actor_update_vnode_bitmap: HashMap<ActorId, Bitmap>,
actor_splits: HashMap<ActorId, Vec<SplitImpl>>,
)
pub(crate) fn pre_apply_reschedule( &mut self, fragment_id: FragmentId, new_actors: HashMap<ActorId, InflightActorInfo>, actor_update_vnode_bitmap: HashMap<ActorId, Bitmap>, actor_splits: HashMap<ActorId, Vec<SplitImpl>>, )
Pre-apply reschedule: update actors, vnode bitmaps, and splits.
The actual removal of old actors happens in post_apply_reschedules.
Sourcepub(crate) fn pre_apply_replace_node_upstream(
&mut self,
fragment_id: FragmentId,
replace_map: &HashMap<FragmentId, FragmentId>,
)
pub(crate) fn pre_apply_replace_node_upstream( &mut self, fragment_id: FragmentId, replace_map: &HashMap<FragmentId, FragmentId>, )
Replace upstream fragment IDs in merge nodes of a fragment’s stream graph.
Sourcepub(crate) fn pre_apply_add_node_upstream(
&mut self,
fragment_id: FragmentId,
new_upstream_info: &PbUpstreamSinkInfo,
)
pub(crate) fn pre_apply_add_node_upstream( &mut self, fragment_id: FragmentId, new_upstream_info: &PbUpstreamSinkInfo, )
Add a new upstream sink node to a fragment’s UpstreamSinkUnion.
Sourcepub(crate) fn pre_apply_drop_node_upstream(
&mut self,
fragment_id: FragmentId,
drop_upstream_fragment_ids: &[FragmentId],
)
pub(crate) fn pre_apply_drop_node_upstream( &mut self, fragment_id: FragmentId, drop_upstream_fragment_ids: &[FragmentId], )
Remove upstream sink nodes from a fragment’s UpstreamSinkUnion.
Sourcepub(crate) fn pre_apply_throttle(
&mut self,
fragment_id: FragmentId,
config: &ThrottleConfig,
)
pub(crate) fn pre_apply_throttle( &mut self, fragment_id: FragmentId, config: &ThrottleConfig, )
Sync inflight nodes.rate_limit so a later reschedule won’t materialize new actors
from stale data. Mirrors controller/streaming_job.rs::update_*_rate_limit_by_*.
Sourcepub(crate) fn pre_apply_split_assignments(
&mut self,
assignments: impl IntoIterator<Item = (FragmentId, HashMap<ActorId, Vec<SplitImpl>>)>,
)
pub(crate) fn pre_apply_split_assignments( &mut self, assignments: impl IntoIterator<Item = (FragmentId, HashMap<ActorId, Vec<SplitImpl>>)>, )
Update split assignments for actors in fragments.
pub(super) fn build_edge( &self, info: Option<(&CreateStreamingJobCommandInfo, bool)>, replace_job: Option<&ReplaceStreamJobPlan>, new_upstream_sink: Option<&UpstreamSinkInfo>, control_stream_manager: &ControlStreamManager, stream_actors: &HashMap<FragmentId, Vec<StreamActor>>, actor_location: &HashMap<ActorId, WorkerId>, ) -> FragmentEdgeBuildResult
Sourcepub(crate) fn post_apply_reschedules(
&mut self,
reschedules: impl IntoIterator<Item = (FragmentId, HashSet<ActorId>)>,
)
pub(crate) fn post_apply_reschedules( &mut self, reschedules: impl IntoIterator<Item = (FragmentId, HashSet<ActorId>)>, )
Post-apply reschedule: remove actors that were marked for removal.
Sourcepub(crate) fn post_apply_remove_fragments(
&mut self,
fragment_ids: impl IntoIterator<Item = FragmentId>,
)
pub(crate) fn post_apply_remove_fragments( &mut self, fragment_ids: impl IntoIterator<Item = FragmentId>, )
Post-apply fragment removal: remove fragments and their jobs if empty.
pub(crate) fn post_apply_remove_job( &mut self, job_id: JobId, ) -> Option<InflightStreamingJobInfo>
Sourceimpl InflightDatabaseInfo
impl InflightDatabaseInfo
pub fn contains_worker(&self, worker_id: WorkerId) -> bool
pub fn existing_table_ids(&self) -> impl Iterator<Item = TableId> + '_