is_iceberg_sink

Function is_iceberg_sink 

pub fn is_iceberg_sink(properties: &BTreeMap<String, String>) -> bool
User-created iceberg sinks have arbitrary names, so identify them by the connector property instead of the __iceberg_sink_ name prefix.