pub struct NotificationManager {
core: Arc<Mutex<NotificationManagerCore>>,
task_tx: UnboundedSender<Task>,
version_generator: Mutex<NotificationVersionGenerator>,
}Expand description
NotificationManager is used to send notification to frontends and compute nodes.
Fields
core: Arc<Mutex<NotificationManagerCore>>task_tx: UnboundedSender<Task>Sender used to add a notification into the waiting queue.
version_generator: Mutex<NotificationVersionGenerator>The current notification version generator.
Implementations
Sourceimpl NotificationManager
impl NotificationManager
Sourcepub(crate) fn notify_streaming_fragment_mapping(
&self,
operation: NotificationOperation,
fragment_mappings: Vec<PbFragmentWorkerSlotMapping>,
)
pub(crate) fn notify_streaming_fragment_mapping( &self, operation: NotificationOperation, fragment_mappings: Vec<PbFragmentWorkerSlotMapping>, )
Notify frontend about streaming worker slot mapping changes.
This only sends streaming mapping updates to frontends. Serving mapping notifications are decoupled and driven by fragment model changes (insert/delete) instead of barrier-driven actor set changes.
Sourcepub(crate) fn notify_serving_fragment_mapping_update(
&self,
fragment_ids: Vec<FragmentId>,
)
pub(crate) fn notify_serving_fragment_mapping_update( &self, fragment_ids: Vec<FragmentId>, )
Notify the serving module about fragment mapping changes.
This should be called when fragments are inserted into or deleted from the meta store, so that serving vnode mappings are kept in sync with the fragment model.
Sourcepub(crate) fn notify_serving_fragment_mapping_delete(
&self,
fragment_ids: Vec<FragmentId>,
)
pub(crate) fn notify_serving_fragment_mapping_delete( &self, fragment_ids: Vec<FragmentId>, )
Notify the serving module about fragment mapping deletions.
This should be called when fragments are deleted from the meta store, so that serving vnode mappings are cleaned up.
Sourceimpl NotificationManager
impl NotificationManager
pub async fn new(meta_store_impl: SqlMetaStore) -> Self
pub fn abort_all(&self)
fn notify( &self, target: Target, operation: Operation, info: Info, version: Option<NotificationVersion>, )
Sourceasync fn notify_with_version(
&self,
target: Target,
operation: Operation,
info: Info,
) -> NotificationVersion
async fn notify_with_version( &self, target: Target, operation: Operation, info: Info, ) -> NotificationVersion
Add a notification to the waiting queue and increase notification version.
Sourcefn notify_without_version(
&self,
target: Target,
operation: Operation,
info: Info,
)
fn notify_without_version( &self, target: Target, operation: Operation, info: Info, )
Add a notification to the waiting queue and return immediately
pub fn notify_snapshot( &self, worker_key: WorkerKey, subscribe_type: SubscribeType, meta_snapshot: MetaSnapshot, )
pub fn notify_all_without_version(&self, operation: Operation, info: Info)
pub async fn notify_frontend( &self, operation: Operation, info: Info, ) -> NotificationVersion
pub async fn notify_frontend_object_info( &self, operation: Operation, object_info: PbObjectInfo, ) -> NotificationVersion
pub async fn notify_hummock( &self, operation: Operation, info: Info, ) -> NotificationVersion
pub async fn notify_compactor( &self, operation: Operation, info: Info, ) -> NotificationVersion
pub fn notify_compute_without_version(&self, operation: Operation, info: Info)
pub fn notify_frontend_without_version(&self, operation: Operation, info: Info)
pub fn notify_hummock_without_version(&self, operation: Operation, info: Info)
pub fn notify_compactor_without_version(&self, operation: Operation, info: Info)
pub fn notify_hummock_with_version( &self, operation: Operation, info: Info, version: Option<NotificationVersion>, )
pub fn notify_local_subscribers(&self, notification: LocalNotification)
Sourcepub fn delete_sender(&self, worker_type: WorkerType, worker_key: WorkerKey)
pub fn delete_sender(&self, worker_type: WorkerType, worker_key: WorkerKey)
Tell NotificationManagerCore to delete sender.
Sourcepub fn insert_sender(
&self,
subscribe_type: SubscribeType,
worker_key: WorkerKey,
sender: UnboundedSender<Notification>,
)
pub fn insert_sender( &self, subscribe_type: SubscribeType, worker_key: WorkerKey, sender: UnboundedSender<Notification>, )
Tell NotificationManagerCore to insert sender by worker_type.
pub fn insert_local_sender(&self, sender: UnboundedSender<LocalNotification>)
pub async fn current_version(&self) -> NotificationVersion