pub trait ValTransaction<TXN>: InMemValTransaction {
// Required method
async fn apply_to_txn(&self, txn: &mut TXN) -> MetadataModelResult<()>;
}Expand description
Trait that wraps a local memory value and applies the change to the local memory value on
commit or leaves the local memory value untouched on abort.
Required Methods
Sourceasync fn apply_to_txn(&self, txn: &mut TXN) -> MetadataModelResult<()>
async fn apply_to_txn(&self, txn: &mut TXN) -> MetadataModelResult<()>
Apply the change (upsert or delete) to txn
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".