SourceSplitAssignment

Type Alias SourceSplitAssignment 

pub type SourceSplitAssignment = HashMap<SourceId, DiscoveredSplits>;
Source-level split assignment: maps source ID to the discovered splits enum. Unlike SplitAssignment, this does not include fragment- or actor-level assignment. The DiscoveredSplits enum is preserved all the way through to the barrier command, and only resolved to concrete per-fragment, per-actor splits when the barrier worker performs the actual split assignment.

Aliased Type

pub struct SourceSplitAssignment { /* private fields */ }