fn build_new_sink_columns(
sink: &PbSink,
removed_column_ids: &HashSet<ColumnId>,
newly_added_columns: &[ColumnCatalog],
) -> Vec<PbColumnCatalog> ⓘExpand description
Build sink column list after removing and appending columns.
fn build_new_sink_columns(
sink: &PbSink,
removed_column_ids: &HashSet<ColumnId>,
newly_added_columns: &[ColumnCatalog],
) -> Vec<PbColumnCatalog> ⓘBuild sink column list after removing and appending columns.