CreateStreamingJobResult

Type Alias CreateStreamingJobResult 

pub type CreateStreamingJobResult = Result<NotificationVersion, (MetaError, bool, Option<Sender<bool>>)>;
The error carries whether the caller should explicitly cancel the creating job and an optional notifier for an awaited cancellation request.

Aliased Type

pub enum CreateStreamingJobResult {
    Ok(u64),
    Err((MetaError, bool, Option<Sender<bool>>)),
}

Variants

1.0.0

Ok(u64)

Contains the success value

1.0.0

Err((MetaError, bool, Option<Sender<bool>>))

Contains the error value