pub(crate) fn materialize_actor_assignments(
actor_id_counter: &AtomicU32,
rendered: RenderedGraph,
) -> RenderedGraphExpand description
Replace preview actor ids with real actor ids after the caller has decided the rendered layout is not a no-op.