async fn run_tick_with_progressive_warn<F>(
source_id: SourceId,
source_name: String,
tick_duration: LabelGuardedHistogram,
fut: F,
) -> F::Outputwhere
F: Future,Expand description
Drive a source worker tick future to completion, recording its duration in tick_duration
and emitting a warn! every TICK_INFLIGHT_WARN_INTERVAL while it is still pending.
The future is never cancelled or timed out, so tick() semantics are unchanged.