pub type CreateStreamingJobResult = Result<NotificationVersion, (MetaError, bool, Option<Sender<bool>>)>;Expand description
The error carries whether the caller should explicitly cancel the creating job and an optional notifier for an awaited cancellation request.
Aliased Type
pub enum CreateStreamingJobResult {
Ok(u64),
Err((MetaError, bool, Option<Sender<bool>>)),
}